@@ -2,27 +2,31 @@
 Treesync 'list' subcommand
 """
 
+from argparse import ArgumentParser, Namespace
+
 from .base import TreesyncCommand
 
+DESCRIPTION = """
+List configured sync targets
+"""
+
 
 class List(TreesyncCommand):
     """
     Tree pull subcommand
     """
+    description = DESCRIPTION
     name = 'list'
 
-    def register_parser_arguments(self, parser):
+    def register_parser_arguments(self, parser: ArgumentParser) -> ArgumentParser:
         """
         Register only common base arguments
         """
         return super().register_common_arguments(parser)
 
-    def run(self, args):
+    def run(self, args: Namespace) -> None:
         """
         List configured sync targets
         """
-        targets = self.filter_targets(args.targets)
-        if not targets:
-            targets = self.config.sync_targets
-        for target in targets:
-            self.message(f'{target}')
+        for target in self.filter_targets(args.targets):
+            self.message(f'{target.name}')
